@@ -122,6 +122,9 @@ public:
 	void invalidateNetworkView();
 	void invalidateAccountDependents();
 
+	void saveColorScheme();
+	void loadColorScheme();
+
 private:
 	shared_ptr<ProgramCollection> dictionaryCollection() const;
 
