@@ -595,13 +595,13 @@ void XHTMLReader::beginParagraph() {
 		myModelReader.addControl(**it);
 		doBlockSpaceBefore =
 			doBlockSpaceBefore ||
-			(*it)->lengthSupported(ZLTextStyleEntry::LENGTH_SPACE_BEFORE);
+			(*it)->lengthSupported(ZLTextStyleEntry::LENGTH_MARGIN_BEFORE);
 	}
 
 	if (doBlockSpaceBefore) {
 		ZLTextStyleEntry blockingEntry;
 		blockingEntry.setLength(
-			ZLTextStyleEntry::LENGTH_SPACE_BEFORE,
+			ZLTextStyleEntry::LENGTH_MARGIN_BEFORE,
 			0,
 			ZLTextStyleEntry::SIZE_UNIT_PIXEL
 		);
@@ -614,12 +614,12 @@ void XHTMLReader::endParagraph() {
 	for (std::vector<shared_ptr<ZLTextStyleEntry> >::const_iterator it = myStyleEntryStack.begin(); it != myStyleEntryStack.end() - myStylesToRemove; ++it) {
 		doBlockSpaceAfter =
 			doBlockSpaceAfter ||
-			(*it)->lengthSupported(ZLTextStyleEntry::LENGTH_SPACE_AFTER);
+			(*it)->lengthSupported(ZLTextStyleEntry::LENGTH_MARGIN_AFTER);
 	}
 	if (doBlockSpaceAfter) {
 		ZLTextStyleEntry blockingEntry;
 		blockingEntry.setLength(
-			ZLTextStyleEntry::LENGTH_SPACE_AFTER,
+			ZLTextStyleEntry::LENGTH_MARGIN_AFTER,
 			0,
 			ZLTextStyleEntry::SIZE_UNIT_PIXEL
 		);
